@@ -1,9 +1,7 @@
 package HTML::FormFu::Imager;
-
-use strict;
-
-our $VERSION = '0.03006';
-$VERSION = eval $VERSION;
+{
+  $HTML::FormFu::Imager::VERSION = '1.00';
+}
 
 1;
 
@@ -24,10 +22,6 @@ given pixel size.
 
 =head1 SUPPORT
 
-Project Page:
-
-L<http://code.google.com/p/html-formfu/>
-
 Mailing list:
 
 L<http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/html-formfu>
@@ -39,24 +33,9 @@ L<http://lists.scsys.co.uk/pipermail/html-formfu/>
 =head1 BUGS
 
 Please submit bugs / feature requests to 
-L<http://code.google.com/p/html-formfu/issues/list> (preferred) or 
+L<https://github.com/fireartist/HTML-FormFu-Imager/issues> (preferred) or 
 L<http://rt.perl.org>.
 
-=head1 SUBVERSION REPOSITORY
-
-The publicly viewable subversion code repository is at 
-L<http://html-formfu.googlecode.com/svn/trunk/HTML-FormFu-Imager>.
-
-If you wish to contribute, you'll need a GMAIL email address. Then just 
-ask on the mailing list for commit access.
-
-If you wish to contribute but for some reason really don't want to sign up 
-for a GMAIL account, please post patches to the mailing list (although  
-you'll have to wait for someone to commit them). 
-
-If you have commit permissions, use the HTTPS repository url: 
-L<https://html-formfu.googlecode.com/svn/trunk/HTML-FormFu-Imager>
-
 =head1 SEE ALSO
 
 L<HTML::FormFu>
@@ -67,7 +46,7 @@ Carl Franks
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 by Carl Franks
+Copyright (C) 2007-2013 by Carl Franks
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
